@@ -15,10 +15,19 @@ if [ ! -e etc/rc.d/rc.bluetooth -o ! -x etc/rc.d/rc.bluetooth ]; then
 else
   chmod 755 etc/rc.d/rc.bluetooth.new
 fi
-config etc/bluetooth/rfcomm.conf.new
-config etc/bluetooth/hcid.conf.new
-config etc/bluetooth/passkeys/default.new
 config etc/rc.d/rc.bluetooth.new
 config etc/rc.d/rc.bluetooth.conf.new
+config etc/bluetooth/asound.conf.new
+config etc/bluetooth/audio.conf.new
+config etc/bluetooth/hcid.conf.new
+config etc/bluetooth/input.conf.new
+config etc/bluetooth/network.conf.new
+config etc/bluetooth/rfcomm.conf.new
+config etc/bluetooth/passkeys/default.new
+config etc/dbus-1/system.d/bluetooth.conf.new
+
+if [ ! -e etc/asound.conf ]; then
+  ( cd etc ; ln -sf bluetooth/asound.conf . )
+fi
 ( cd etc/bluetooth ; rm -rf README.SLACKWARE )
-( cd etc/bluetooth ; ln -sf /usr/doc/bluez-utils-3.9/README.SLACKWARE README.SLACKWARE )
+( cd etc/bluetooth ; ln -sf /usr/doc/bluez-utils-3.36/README.SLACKWARE README.SLACKWARE )
